@@ -42,14 +42,14 @@ class dynamic_method():
         row -= 1
         p = pos_mapping[row]
         start_row, end_row = p[0], p[-1]
-        start = start_row
+        start = start_row - 1
         align = Alignment(horizontal='center', vertical='center', wrap_text=True)
-        for i in range(start_row + 1, end_row):
+        for i in range(start_row, end_row):
             current_cell, prev_cell = pos[i][col], pos[i - 1][col]
             if isinstance(current_cell, Cell) and isinstance(prev_cell, Cell) and current_cell.value != prev_cell.value:
-                sheet.merge_cells(start_row=start, start_column=col + 1, end_column=col + 1, end_row=i - 1)
-                sheet[num_to_pos_char((col + 1, start))].alignment = align
+                sheet.merge_cells(start_row=start + 1, start_column=col + 1, end_column=col + 1, end_row=i)
+                sheet[num_to_pos_char((col + 1, start + 1))].alignment = align
                 start = i
         if end_row - start > 1:
-            sheet[num_to_pos_char((col + 1, start))].alignment = align
-            sheet.merge_cells(start_row=start, start_column=col + 1, end_column=col + 1, end_row=end_row)
\ No newline at end of file
+            sheet.merge_cells(start_row=start + 1, start_column=col + 1, end_column=col + 1, end_row=end_row)
+            sheet[num_to_pos_char((col + 1, start + 1))].alignment = align
\ No newline at end of file
